==> leadlink_open_api-0.0.14.tar.gz: lib/api_product_category.dart <==

part of leadlinkopenapi;

class APIProductCategory {

  // 获取所有品类列表
  static void getCategoryList(bool isOnDisplay,{Function(List<ProductCategory> productCategoryList) onSucc, Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<ProductCategory>(ProductCategory())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isOnDisplay', isOnDisplay);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<ProductCategory>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }

  // 获取用户拥有的产品下的品类列表
  static getCategoryListByUser({Function(List<ProductCategory>) onSucc, Function(String) onFail}) async {
    APIScheme.getAllSchemeListByCurrentUser(
      onFail: onFail,
      onSucc: (schemes) {
        List<ProductCategory> datas = _filterUniqueCategory(schemes);
        if (onSucc != null) onSucc(datas);
      },
    );
  }

  // 分类去重
  static List<ProductCategory> _filterUniqueCategory(List<UserScheme> input) {

    List<ProductCategory> categoryList = [];
   
    if (input == null) return categoryList;
    if (input.length == 0) return categoryList;

    // 取 scheme并去重
     List<UserScheme> result = [];
    for (int i = 0; i < input.length; i++) {

      UserScheme scheme = input[i];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;

      final isRepeat = _isFoundRepeat(catId, result);

      if (isRepeat == false) {
        result.add(scheme);
      }
    }

    for (int p = 0; p < result.length; p++) {
      UserScheme scheme= result[p];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      categoryList.add(category);
    }
    return categoryList;
  }

  // 判断重复
  static bool _isFoundRepeat(int pickerCategoryId, List<UserScheme> tempList) {
    for (int k = 0; k < tempList.length; k++) {
      UserScheme scheme = tempList[k];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;
      if (pickerCategoryId.compareTo(catId) == 0) {
        return true;
      }
    }
    return false;
  } 
}

==> leadlink_open_api-0.0.21.tar.gz: lib/api_product_category.dart <==

part of leadlinkopenapi;

class APIProductCategory {

  // 获取所有品类列表
  static void getCategoryList({bool isOnDisplay,Function(List<ProductCategory> productCategoryList) onSucc, Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<ProductCategory>(ProductCategory());
      
      queryBuider.whereNotEqualTo('isActive', false);
      if(isOnDisplay != null) {
        queryBuider.whereEqualTo('isOnDisplay', isOnDisplay);
      }

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<ProductCategory>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }

  // 获取用户拥有的产品下的品类列表
  static getCategoryListByUser({Function(List<ProductCategory>) onSucc, Function(String) onFail}) async {
    APIScheme.getAllSchemeListByCurrentUser(
      onFail: onFail,
      onSucc: (schemes) {
        List<ProductCategory> datas = _filterUniqueCategory(schemes);
        if (onSucc != null) onSucc(datas);
      },
    );
  }

  // 分类去重
  static List<ProductCategory> _filterUniqueCategory(List<UserScheme> input) {

    List<ProductCategory> categoryList = [];
   
    if (input == null) return categoryList;
    if (input.length == 0) return categoryList;

    // 取 scheme并去重
     List<UserScheme> result = [];
    for (int i = 0; i < input.length; i++) {

      UserScheme scheme = input[i];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;

      final isRepeat = _isFoundRepeat(catId, result);

      if (isRepeat == false) {
        result.add(scheme);
      }
    }

    for (int p = 0; p < result.length; p++) {
      UserScheme scheme= result[p];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      categoryList.add(category);
    }
    return categoryList;
  }

  // 判断重复
  static bool _isFoundRepeat(int pickerCategoryId, List<UserScheme> tempList) {
    for (int k = 0; k < tempList.length; k++) {
      UserScheme scheme = tempList[k];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;
      if (pickerCategoryId.compareTo(catId) == 0) {
        return true;
      }
    }
    return false;
  } 
}
